@@ -1,14 +1,15 @@
 package Tree::Template::Declare;
+{
+  $Tree::Template::Declare::DIST = 'Tree-Template-Declare';
+}
+$Tree::Template::Declare::VERSION = '0.7';
 use strict;
 use warnings;
 use Sub::Exporter;
 use Devel::Caller 'caller_args';
 use Carp;
-use Data::Dumper;
 use 5.006;
 
-our $VERSION='0.6';
-
 {
 my $exporter=Sub::Exporter::build_exporter({
     groups => {
@@ -100,12 +101,19 @@ sub _build_group {
 }
 
 1;
-__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Tree::Template::Declare - easily build tree structures
 
+=head1 VERSION
+
+version 0.7
+
 =head1 SYNOPSIS
 
  use Tree::Template::Declare builder => '+DAG_Node';
@@ -296,4 +304,16 @@ for the creation of detached nodes
 
 Gianni Ceccarelli <dakkar@thenautilus.net>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Gianni Ceccarelli <dakkar@thenautilus.net>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+__END__
+
+# ABSTRACT: easily build tree structures
+
