@@ -1,10 +1,12 @@
 package Tree::Template::Declare::DAG_Node;
+{
+  $Tree::Template::Declare::DAG_Node::DIST = 'Tree-Template-Declare';
+}
+$Tree::Template::Declare::DAG_Node::VERSION = '0.7';
 use strict;
 use warnings;
 use Carp;
 
-our $VERSION='0.6';
-
 sub new {
     my ($class,$node_class)=@_;
     $node_class||='Tree::DAG_Node';
@@ -61,11 +63,18 @@ sub set_node_attributes {
 }
 
 1;
-__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-Tree::Template::Declare::DAG_Node
+Tree::Template::Declare::DAG_Node - adaptor for Tree::DAG_Node
+
+=head1 VERSION
+
+version 0.7
 
 =head1 SYNOPSIS
 
@@ -84,8 +93,22 @@ method.
      Tree::Template::Declare::DAG_Node->new('Tree::DAG_Node::XPath');
      # custom class
 
+=for Pod::Coverage add_child_node finalize_tree new new_node new_tree set_node_attributes set_node_name
+
 =head1 AUTHOR
 
 Gianni Ceccarelli <dakkar@thenautilus.net>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Gianni Ceccarelli <dakkar@thenautilus.net>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+__END__
+
+# ABSTRACT: adaptor for Tree::DAG_Node
+
