@@ -1,11 +1,13 @@
 package Tree::Template::Declare::HTML_Element;
+{
+  $Tree::Template::Declare::HTML_Element::DIST = 'Tree-Template-Declare';
+}
+$Tree::Template::Declare::HTML_Element::VERSION = '0.7';
 use strict;
 use warnings;
 use Carp;
 use HTML::Element;
 
-our $VERSION='0.6';
-
 sub new {
     my ($class)=@_;
 
@@ -76,11 +78,18 @@ sub set_node_attributes {
 }
 
 1;
-__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-Tree::Template::Declare::HTML_Element
+Tree::Template::Declare::HTML_Element - adaptor for HTML::Element
+
+=head1 VERSION
+
+version 0.7
 
 =head1 SYNOPSIS
 
@@ -104,8 +113,22 @@ which is too cumbersone. You can instead use:
 HTML::Element's C<deobjectify_text> method will be called by
 C<finalize_tree> before returning the tree object.
 
+=for Pod::Coverage add_child_node finalize_tree new new_node new_tree set_node_attributes set_node_name
+
 =head1 AUTHOR
 
 Gianni Ceccarelli <dakkar@thenautilus.net>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Gianni Ceccarelli <dakkar@thenautilus.net>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+__END__
+
+# ABSTRACT: adaptor for HTML::Element
+
