@@ -1,11 +1,13 @@
 package Tree::Template::Declare::LibXML;
+{
+  $Tree::Template::Declare::LibXML::DIST = 'Tree-Template-Declare';
+}
+$Tree::Template::Declare::LibXML::VERSION = '0.7';
 use strict;
 use warnings;
 use Carp;
 use XML::LibXML;
 
-our $VERSION='0.6';
-
 sub new {
     my ($class)=@_;
 
@@ -110,11 +112,18 @@ sub set_node_attributes {
 }
 
 1;
-__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-Tree::Template::Declare::LibXML
+Tree::Template::Declare::LibXML - adaptor for LibXML
+
+=head1 VERSION
+
+version 0.7
 
 =head1 SYNOPSIS
 
@@ -143,8 +152,22 @@ This is ugly, so you can do:
    text_node 'some text content';
  };
 
+=for Pod::Coverage add_child_node finalize_tree new new_node new_tree set_node_attributes set_node_name
+
 =head1 AUTHOR
 
 Gianni Ceccarelli <dakkar@thenautilus.net>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Gianni Ceccarelli <dakkar@thenautilus.net>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+__END__
+
+# ABSTRACT: adaptor for LibXML
+
